Module utils

Module utils 

Core utility functions

This module contains utility functions used throughout the core module.

Functions

get_repo_name_from_url
Get the repository name from a URL
is_git_ssh_url
Check if a path looks like a git SSH URL
is_main_branch
Check if a branch name is a main branch (shouldn’t be deleted)
ssh_to_https_url
Convert SSH URL to HTTPS URL for cloning